@@ -8,10 +8,14 @@ wetherill <- function(x,i=1,format){
     out <- list()
     if (format < 4) labels <- c('Pb207U235','Pb206U238')
     else if (format < 7) labels <- c('Pb207U235','Pb206U238','Pb204U238')
+    else if (format==9) labels <- c('Pb206U238','Pb204U238')
+    else if (format==10) labels <- c('Pb207U235','Pb204U235')
+    else if (format==11) labels <- c('Pb206U238','Pb208Th232','Th232U238')
+    else if (format==12) labels <- c('Pb207U235','Pb208Th232','Th232U238')
     else labels <- c('Pb207U235','Pb206U238','Pb208Th232','Th232U238')
     if (format %in% c(1,3)){
         out$x <- X[i,labels]
-        out$cov <- cor2cov2(X[i,'errPb207U235'],X[i,'errPb206U238'],X[i,'rhoXY'])
+        out$cov <- cor2cov2(X[i,'errPb207U235'],X[i,'errPb206U238'],X[i,'rXY'])
     } else if (format == 2){
         U238U235 <- iratio('U238U235')[1]
         Pb207U235 <- U238U235*X[i,'Pb207Pb206']/X[i,'U238Pb206']
@@ -21,13 +25,13 @@ wetherill <- function(x,i=1,format){
         J[1,1] <- -Pb207U235/X[i,'U238Pb206']
         J[1,2] <- U238U235/X[i,'U238Pb206']
         J[2,1] <- -1/X[i,'U238Pb206']^2
-        E <- cor2cov2(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],X[i,'rhoXY'])
+        E <- cor2cov2(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],X[i,'rXY'])
         out$cov <- J %*% E %*% t(J)
     } else if (format == 4){
         out$x <- X[i,labels]
         out$cov <- cor2cov3(X[i,'errPb207U235'],X[i,'errPb206U238'],
-                            X[i,'errPb204U238'],X[i,'rhoXY'],
-                            X[i,'rhoXZ'],X[i,'rhoYZ'])
+                            X[i,'errPb204U238'],X[i,'rXY'],
+                            X[i,'rXZ'],X[i,'rYZ'])
     } else if (format == 5){
         U238U235 <- iratio('U238U235')[1]
         Pb207U235 <- U238U235*X[i,'Pb207Pb206']/X[i,'U238Pb206']
@@ -41,8 +45,8 @@ wetherill <- function(x,i=1,format){
         J[3,1] <- -Pb204U238/X[i,'U238Pb206']
         J[3,3] <- 1/X[i,'U238Pb206']
         E <- cor2cov3(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],
-                      X[i,'errPb204Pb206'],X[i,'rhoXY'],
-                      X[i,'rhoXZ'],X[i,'rhoYZ'])
+                      X[i,'errPb204Pb206'],X[i,'rXY'],
+                      X[i,'rXZ'],X[i,'rYZ'])
         out$cov <- J %*% E %*% t(J)        
     } else if (format == 6){
         out$x <- X[i,labels]
@@ -68,8 +72,8 @@ wetherill <- function(x,i=1,format){
         out$x <- X[i,labels]
         out$cov <- cor2cov4(X[i,'errPb207U235'],X[i,'errPb206U238'],
                             X[i,'errPb208Th232'],X[i,'errTh232U238'],
-                            X[i,'rhoXY'],X[i,'rhoXZ'],X[i,'rhoXW'],
-                            X[i,'rhoYZ'],X[i,'rhoYW'],X[i,'rhoZW'])
+                            X[i,'rXY'],X[i,'rXZ'],X[i,'rXW'],
+                            X[i,'rYZ'],X[i,'rYW'],X[i,'rZW'])
     } else if (format == 8){
         U238U235 <- iratio('U238U235')[1]
         Pb207U235 <- U238U235*X[i,'Pb207Pb206']/X[i,'U238Pb206']
@@ -87,8 +91,57 @@ wetherill <- function(x,i=1,format){
         J[4,4] <- 1
         E <- cor2cov4(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],
                       X[i,'errPb208Pb206'],X[i,'errTh232U238'],
-                      X[i,'rhoXY'],X[i,'rhoXZ'],X[i,'rhoXW'],
-                      X[i,'rhoYZ'],X[i,'rhoYW'],X[i,'rhoZW'])
+                      X[i,'rXY'],X[i,'rXZ'],X[i,'rXW'],
+                      X[i,'rYZ'],X[i,'rYW'],X[i,'rZW'])
+        out$cov <- J %*% E %*% t(J)
+    } else if (format == 9){
+        Pb206U238 <- 1/X[i,'U238Pb206']
+        Pb204U238 <- X[i,'Pb204Pb206']/X[i,'U238Pb206']
+        out$x <- c(Pb206U238,Pb204U238)
+        J <- matrix(0,2,2)
+        J[1,1] <- -Pb206U238/X[i,'U238Pb206']
+        J[2,1] <- -Pb204U238/X[i,'U238Pb206']
+        J[2,2] <- 1/X[i,'U238Pb206']
+        E <- cor2cov2(X[i,'errU238Pb206'],X[i,'errPb204Pb206'],X[i,'rXY'])
+        out$cov <- J %*% E %*% t(J)
+    } else if (format == 10){
+        Pb207U235 <- 1/X[i,'U235Pb207']
+        Pb204U235 <- X[i,'Pb204Pb207']/X[i,'U235Pb207']
+        out$x <- c(Pb207U235,Pb204U235)
+        J <- matrix(0,2,2)
+        J[1,1] <- -Pb207U235/X[i,'U235Pb207']
+        J[2,1] <- -Pb204U235/X[i,'U235Pb207']
+        J[2,2] <- 1/X[i,'U235Pb207']
+        E <- cor2cov2(X[i,'errU235Pb207'],X[i,'errPb204Pb207'],X[i,'rXY'])
+        out$cov <- J %*% E %*% t(J)
+    } else if (format == 11){
+        Pb206U238 <- 1/X[i,'U238Pb206']
+        Pb208Th232 <- X[i,'Pb208Pb206']/(X[i,'U238Pb206']*X[i,'Th232U238'])
+        Th232U238 <- X[i,'Th232U238']
+        out$x <- c(Pb206U238,Pb208Th232,Th232U238)
+        J <- matrix(0,3,3)
+        J[1,1] <- -Pb206U238/X[i,'U238Pb206']
+        J[2,1] <- -Pb208Th232/X[i,'U238Pb206']
+        J[2,2] <- 1/(X[i,'U238Pb206']*X[i,'Th232U238'])
+        J[2,3] <- -Pb208Th232/X[i,'Th232U238']
+        J[3,3] <- 1
+        E <- cor2cov3(X[i,'errU238Pb206'],X[i,'errPb208Pb206'],X[i,'errTh232U238'],
+                      X[i,'rXY'],X[i,'rXZ'],X[i,'rYZ'])
+        out$cov <- J %*% E %*% t(J)
+    } else if (format == 12){
+        U238U235 <- iratio('U238U235')[1]
+        Pb207U235 <- 1/X[i,'U235Pb207']
+        Pb208Th232 <- X[i,'Pb208Pb207']/(X[i,'U235Pb207']*U238U235*X[i,'Th232U238'])
+        Th232U238 <- X[i,'Th232U238']
+        out$x <- c(Pb207U235,Pb208Th232,Th232U238)
+        J <- matrix(0,3,3)
+        J[1,1] <- -Pb207U235/X[i,'U235Pb207']
+        J[2,1] <- -Pb208Th232/X[i,'U235Pb207']
+        J[2,2] <- 1/(X[i,'U235Pb207']*U238U235*X[i,'Th232U238'])
+        J[2,3] <- -Pb208Th232/X[i,'Th232U238']
+        J[3,3] <- 1
+        E <- cor2cov3(X[i,'errU235Pb207'],X[i,'errPb208Pb207'],X[i,'errTh232U238'],
+                      X[i,'rXY'],X[i,'rXZ'],X[i,'rYZ'])
         out$cov <- J %*% E %*% t(J)        
     }
     names(out$x) <- labels
@@ -107,7 +160,10 @@ tera.wasserburg <- function(x,i=1,format){
     out <- list()
     if (format < 4) labels <- c('U238Pb206','Pb207Pb206')
     else if (format < 7) labels <- c('U238Pb206','Pb207Pb206','Pb204Pb206')
-    else labels <- c('U238Pb206','Pb207Pb206','Pb208Pb206','Th232U238')
+    else if (format < 9) labels <- c('U238Pb206','Pb207Pb206','Pb208Pb206','Th232U238')
+    else if (format == 9) labels <- c('U238Pb206','Pb204Pb206')
+    else if (format == 11) labels <- c('U238Pb206','Pb208Pb206','Th232U238')
+    else stop('tera.wasserburg() is not available for this U-Pb format')
     if (format==1){
         U238U235 <- iratio('U238U235')[1]
         U238Pb206 <- 1/X[i,'Pb206U238']
@@ -116,19 +172,19 @@ tera.wasserburg <- function(x,i=1,format){
         J[1,2] <- -1/X[i,'Pb206U238']^2
         J[2,1] <- 1/(X[i,'Pb206U238']*U238U235)
         J[2,2] <- -Pb207Pb206/X[i,'Pb206U238']
-        E <- cor2cov2(X[i,'errPb207U235'],X[i,'errPb206U238'],X[i,'rhoXY'])
+        E <- cor2cov2(X[i,'errPb207U235'],X[i,'errPb206U238'],X[i,'rXY'])
         out$x <- c(U238Pb206,Pb207Pb206)
         out$cov <- J %*% E %*% t(J)
     } else if (format == 2){
         out$x <- X[i,labels]
         out$cov <- matrix(0,2,2)
         diag(out$cov) <- X[i,c('errU238Pb206','errPb207Pb206')]^2
-        out$cov <- cor2cov2(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],X[i,'rhoXY'])
+        out$cov <- cor2cov2(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],X[i,'rXY'])
     } else if (format == 3){
         U238Pb206 <- 1/X[i,'Pb206U238']
         out$x <- c(U238Pb206,X[i,'Pb207Pb206'])
         J <- matrix(0,2,2)
-        E <- cor2cov2(X[i,'errPb206U238'],X[i,'errPb207Pb206'],X[i,'rhoYZ'])
+        E <- cor2cov2(X[i,'errPb206U238'],X[i,'errPb207Pb206'],X[i,'rYZ'])
         J[1,1] <- -U238Pb206^2
         J[2,2] <- 1
         out$cov <- J %*% E %*% t(J)
@@ -138,8 +194,8 @@ tera.wasserburg <- function(x,i=1,format){
         Pb207Pb206 <- X[i,'Pb207U235']/(X[i,'Pb206U238']*U238U235)
         Pb204Pb206 <- X[i,'Pb204U238']/X[i,'Pb206U238']
         E <- cor2cov3(X[i,'errPb207U235'],X[i,'errPb206U238'],
-                      X[i,'errPb204U238'],X[i,'rhoXY'],
-                      X[i,'rhoXZ'],X[i,'rhoYZ'])
+                      X[i,'errPb204U238'],X[i,'rXY'],
+                      X[i,'rXZ'],X[i,'rYZ'])
         J <- matrix(0,3,3)
         J[1,2] <- -U238Pb206/X[i,'Pb206U238']
         J[2,1] <- 1/(X[i,'Pb206U238']*U238U235)
@@ -154,7 +210,7 @@ tera.wasserburg <- function(x,i=1,format){
         diag(out$cov) <- X[i,c('errU238Pb206','errPb207Pb206','errPb204Pb206')]^2
         out$cov <-
             cor2cov3(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],X[i,'errPb204Pb206'],
-                     X[i,'rhoXY'],X[i,'rhoXZ'],X[i,'rhoYZ'])
+                     X[i,'rXY'],X[i,'rXZ'],X[i,'rYZ'])
     } else if (format == 6){
         U238Pb206 <- 1/X[i,'Pb206U238']
         Pb207Pb206 <- X[i,'Pb207Pb206']
@@ -184,8 +240,8 @@ tera.wasserburg <- function(x,i=1,format){
         Th232U238 <- X[i,'Th232U238']
         E <- cor2cov4(X[i,'errPb207U235'],X[i,'errPb206U238'],
                       X[i,'errPb208Th232'],X[i,'errTh232U238'],
-                      X[i,'rhoXY'],X[i,'rhoXZ'],X[i,'rhoXW'],
-                      X[i,'rhoYZ'],X[i,'rhoYW'],X[i,'rhoZW'])
+                      X[i,'rXY'],X[i,'rXZ'],X[i,'rXW'],
+                      X[i,'rYZ'],X[i,'rYW'],X[i,'rZW'])
         J <- matrix(0,4,4)
         J[1,2] <- -U238Pb206/X[i,'Pb206U238']
         J[2,1] <- 1/(X[i,'Pb206U238']*U238U235)
@@ -200,8 +256,17 @@ tera.wasserburg <- function(x,i=1,format){
         out$x <- X[i,labels]
         out$cov <- cor2cov4(X[i,'errU238Pb206'],X[i,'errPb207Pb206'],
                             X[i,'errPb208Pb206'],X[i,'errTh232U238'],
-                            X[i,'rhoXY'],X[i,'rhoXZ'],X[i,'rhoXW'],
-                            X[i,'rhoYZ'],X[i,'rhoYW'],X[i,'rhoZW'])
+                            X[i,'rXY'],X[i,'rXZ'],X[i,'rXW'],
+                            X[i,'rYZ'],X[i,'rYW'],X[i,'rZW'])
+    } else if (format == 9){
+        out$x <- X[i,labels]
+        out$cov <- matrix(0,2,2)
+        diag(out$cov) <- X[i,c('errU238Pb206','errPb204Pb206')]^2
+        out$cov <- cor2cov3(X[i,'errU238Pb206'],X[i,'errPb204Pb206'],X[i,'rXY'])
+    } else if (format == 11){
+        out$x <- X[i,labels]
+        out$cov <- cor2cov3(X[i,'errU238Pb206'],X[i,'errPb208Pb206'],X[i,'errTh232U238'],
+                            X[i,'rXY'],X[i,'rXZ'],X[i,'rYZ'])
     }
     names(out$x) <- labels
     colnames(out$cov) <- labels
@@ -246,12 +311,16 @@ get.UPb.isochron.ratios.204 <- function(x,i=NULL){
     out
 }
 get.UPb.isochron.ratios.208 <- function(x,i=NULL,tt=0){
-    if (x$format>6){
-        labels <- c('U238Pb206','Pb208cPb206','U235Pb207',
-                    'Pb208cPb207','Th232U238','Th232Pb208',
-                    'Pb206cPb208','Pb207cPb208')
+    if (x$format%in%c(7,8)){
+    labels <- c('U238Pb206','Pb208cPb206','U235Pb207',
+                'Pb208cPb207','Th232U238','Th232Pb208',
+                'Pb206cPb208','Pb207cPb208')
+    } else if (x$format==11){
+        labels <- c('U238Pb206','Pb208cPb206','Th232U238')
+    } else if (x$format==12){
+        labels <- c('U235Pb207','Pb208cPb207','Th232U238')
     } else {
-        stop('Incorrect input format for the get.UPb.isochron.ratios.208 function.')
+        stop('Invalid format for get.UPb.isochron.ratios.208')
     }
     if (is.null(i)){
         ns <- length(x)
@@ -261,45 +330,82 @@ get.UPb.isochron.ratios.208 <- function(x,i=NULL,tt=0){
         }
         colnames(out) <- labels
         return(out)
+    } else if (x$format%in%c(7,8)){
+        McL <- mclean(tt,d=x$d[i])
+        l2 <- settings('lambda','Th232')[1]
+        U85 <- iratio('U238U235')[1]
+        tw <- tera.wasserburg(x,i) # 38/06, 07/06, 08/06, 32/38
+        U8Pb6 <- tw$x['U238Pb206']
+        Pb8c6 <- tw$x['Pb208Pb206'] -
+            tw$x['Th232U238']*tw$x['U238Pb206']*McL$Pb208Th232
+        U5Pb7 <- tw$x['U238Pb206']/(U85*tw$x['Pb207Pb206'])
+        Pb8c7 <- Pb8c6/tw$x['Pb207Pb206']
+        Th2Pb8 <- tw$x['Th232U238']*tw$x['U238Pb206']/tw$x['Pb208Pb206']
+        Pb6c8 <- 1/tw$x['Pb208Pb206'] -
+            McL$Pb206U238*tw$x['U238Pb206']/tw$x['Pb208Pb206']
+        Pb7c8 <- tw$x['Pb207Pb206']/tw$x['Pb208Pb206'] -
+            McL$Pb207U235*tw$x['U238Pb206']/(U85*tw$x['Pb208Pb206'])
+        J <- matrix(0,8,4)
+        J[1,1] <- 1
+        J[2,1] <- -tw$x['Th232U238']*(exp(l2*tt)-1)
+        J[2,3] <- 1
+        J[2,4] <- -tw$x['U238Pb206']*(exp(l2*tt)-1)
+        J[3,1] <- 1/(U85*tw$x['Pb207Pb206'])
+        J[3,2] <- -U5Pb7/tw$x['Pb207Pb206']
+        J[4,1] <- J[2,1]/tw$x['Pb207Pb206']
+        J[4,2] <- -Pb8c7/tw$x['Pb207Pb206']
+        J[4,3] <- J[2,3]/tw$x['Pb207Pb206']
+        J[4,4] <- J[2,4]/tw$x['Pb207Pb206']
+        J[5,4] <- 1
+        J[6,1] <- tw$x['Th232U238']/tw$x['Pb208Pb206']
+        J[6,3] <- -Th2Pb8/tw$x['Pb208Pb206']
+        J[6,4] <- tw$x['U238Pb206']/tw$x['Pb208Pb206']
+        J[7,1] <- -McL$Pb206U238/tw$x['Pb208Pb206']
+        J[7,3] <- -Pb6c8/tw$x['Pb208Pb206']
+        J[8,1] <- -McL$Pb207U235/(U85*tw$x['Pb208Pb206'])
+        J[8,2] <- 1/tw$x['Pb208Pb206']
+        J[8,3] <- -Pb7c8/tw$x['Pb208Pb206']
+        out <- list()
+        out$x <- c(U8Pb6,Pb8c6,U5Pb7,Pb8c7,
+                   tw$x['Th232U238'],Th2Pb8,Pb6c8,Pb7c8)
+        E <- tw$cov
+    } else if (x$format==11){
+        l2 <- settings('lambda','Th232')[1]
+        U8Pb6 <- x$x[i,'U238Pb206']
+        Pb8c6 <- x$x[i,'Pb208Pb206'] -
+            x$x[i,'Th232U238']*x$x[i,'U238Pb206']*(exp(l2*tt)-1)
+        J <- diag(3)
+        J[2,1] <- -x$x[i,'Th232U238']*(exp(l2*tt)-1)
+        J[2,3] <- -x$x[i,'U238Pb206']*(exp(l2*tt)-1)
+        out <- list()
+        out$x <- c(U8Pb6,Pb8c6,x$x[i,'Th232U238'])
+        E <- cor2cov3(sX=x$x[i,'errU238Pb206'],
+                      sY=x$x[i,'errPb208Pb206'],
+                      sZ=x$x[i,'errTh232U238'],
+                      rXY=x$x[i,'rXY'],
+                      rXZ=x$x[i,'rXZ'],
+                      rYZ=x$x[i,'rYZ'])
+    } else if (x$format==12){
+        U85 <- iratio('U238U235')[1]
+        l2 <- settings('lambda','Th232')[1]
+        U5Pb7 <- x$x[i,'U235Pb207']
+        Pb8c7 <- x$x[i,'Pb208Pb207'] -
+            x$x[i,'Th232U238']*U85*x$x[i,'U235Pb207']*(exp(l2*tt)-1)
+        J <- diag(3)
+        J[2,1] <- -x$x[i,'Th232U238']*U85*(exp(l2*tt)-1)
+        J[2,3] <- -x$x[i,'U235Pb207']*U85*(exp(l2*tt)-1)
+        out <- list()
+        out$x <- c(U5Pb7,Pb8c7,x$x[i,'Th232U238'])
+        E <- cor2cov3(sX=x$x[i,'errU235Pb207'],
+                      sY=x$x[i,'errPb208Pb207'],
+                      sZ=x$x[i,'errTh232U238'],
+                      rXY=x$x[i,'rXY'],
+                      rXZ=x$x[i,'rXZ'],
+                      rYZ=x$x[i,'rYZ'])
+    } else {
+        stop('Invalid U-Pb format for get.UPb.isochron.ratios.208')
     }
-    D <- mclean(tt,d=x$d[i])
-    l2 <- settings('lambda','Th232')[1]
-    U <- iratio('U238U235')[1]
-    tw <- tera.wasserburg(x,i) # 38/06, 07/06, 08/06, 32/38
-    U8Pb6 <- tw$x['U238Pb206']
-    Pb8c6 <- tw$x['Pb208Pb206'] -
-        tw$x['Th232U238']*tw$x['U238Pb206']*(exp(l2*tt)-1)
-    U5Pb7 <- tw$x['U238Pb206']/(U*tw$x['Pb207Pb206'])
-    Pb8c7 <- Pb8c6/tw$x['Pb207Pb206']
-    Th2Pb8 <- tw$x['Th232U238']*tw$x['U238Pb206']/tw$x['Pb208Pb206']
-    Pb6c8 <- 1/tw$x['Pb208Pb206'] -
-        D$Pb206U238*tw$x['U238Pb206']/tw$x['Pb208Pb206']
-    Pb7c8 <- tw$x['Pb207Pb206']/tw$x['Pb208Pb206'] -
-        D$Pb207U235*tw$x['U238Pb206']/(U*tw$x['Pb208Pb206'])
-    J <- matrix(0,8,4)
-    J[1,1] <- 1
-    J[2,1] <- -tw$x['Th232U238']*(exp(l2*tt)-1)
-    J[2,3] <- 1
-    J[2,4] <- -tw$x['U238Pb206']*(exp(l2*tt)-1)
-    J[3,1] <- 1/(U*tw$x['Pb207Pb206'])
-    J[3,2] <- -U5Pb7/tw$x['Pb207Pb206']
-    J[4,1] <- J[2,1]/tw$x['Pb207Pb206']
-    J[4,2] <- -Pb8c7/tw$x['Pb207Pb206']
-    J[4,3] <- J[2,3]/tw$x['Pb207Pb206']
-    J[4,4] <- J[2,4]/tw$x['Pb207Pb206']
-    J[5,4] <- 1
-    J[6,1] <- tw$x['Th232U238']/tw$x['Pb208Pb206']
-    J[6,3] <- -Th2Pb8/tw$x['Pb208Pb206']
-    J[6,4] <- tw$x['U238Pb206']/tw$x['Pb208Pb206']
-    J[7,1] <- -D$Pb206U238/tw$x['Pb208Pb206']
-    J[7,3] <- -Pb6c8/tw$x['Pb208Pb206']
-    J[8,1] <- -D$Pb207U235/(U*tw$x['Pb208Pb206'])
-    J[8,2] <- 1/tw$x['Pb208Pb206']
-    J[8,3] <- -Pb7c8/tw$x['Pb208Pb206']
-    out <- list()
-    out$x <- c(U8Pb6,Pb8c6,U5Pb7,Pb8c7,
-               tw$x['Th232U238'],Th2Pb8,Pb6c8,Pb7c8)
-    out$cov <- J %*% tw$cov %*% t(J)
+    out$cov <- J %*% E %*% t(J)
     names(out$x) <- labels
     colnames(out$cov) <- labels
     rownames(out$cov) <- labels
@@ -309,19 +415,19 @@ get.UPb.isochron.ratios.208 <- function(x,i=NULL,tt=0){
 w2tw <- function(w,format){
     if (format %in% c(1,2,3)){
         cnames <- c('U238Pb206','errU238Pb206',
-                    'Pb207Pb206','errPb207Pb206','rhoXY')
+                    'Pb207Pb206','errPb207Pb206','rXY')
     } else if (format%in%c(4,5,6)){
         cnames <- c('U238Pb206','errU238Pb206',
                     'Pb207Pb206','errPb207Pb206',
                     'Pb206Pb206','errPb204Pb206',
-                    'rhoXY','rhoXZ','rhoYZ')
+                    'rXY','rXZ','rYZ')
     } else if (format%in%c(7,8)){
         cnames <- c('U238Pb206','errU238Pb206',
                     'Pb207Pb206','errPb207Pb206',
                     'Pb208Pb206','errPb208Pb206',
                     'Th232U238','errTh232U238',
-                    'rhoXY','rhoXZ','rhoXW',
-                    'rhoYZ','rhoYW','rhoZW')
+                    'rXY','rXZ','rXW',
+                    'rYZ','rYW','rZW')
     } else {
         stop('Invalid input format.')
     }
@@ -338,19 +444,19 @@ w2tw <- function(w,format){
 tw2w <- function(tw,format){
     if (format %in% c(1,2,3)){
         cnames <- c('Pb207U235','errPb207U235',
-                    'Pb206U238','errPb206U238','rhoXY')
+                    'Pb206U238','errPb206U238','rXY')
     } else if (format%in%c(4,5,6)){
         cnames <- c('Pb207U235','errPb207U235',
                     'Pb206U238','errPb206U238',
                     'Pb204U238','errPb204U238',
-                    'rhoXY','rhoXZ','rhoYZ')
+                    'rXY','rXZ','rYZ')
     } else if (format%in%c(7,8)){
         cnames <- c('Pb207U235','errPb207U235',
                     'Pb206U238','errPb206U238',
                     'Pb208Th232','errPb208Th232',
                     'Th232U238','errTh232U238',
-                    'rhoXY','rhoXZ','rhoXW',
-                    'rhoYZ','rhoYW','rhoZW')
+                    'rXY','rXZ','rXW',
+                    'rYZ','rYW','rZW')
     } else {
         stop('Invalid input format.')
     }
@@ -374,19 +480,19 @@ wtw_helper <- function(x,covmat,cnames){
     cormat[pos,pos] <- stats::cov2cor(covmat[pos,pos])
     out[c(1,3)] <- x[1:2]
     out[c(2,4)] <- err[1:2]
-    out['rhoXY'] <- cormat[1,2]
+    out['rXY'] <- cormat[1,2]
     if (nc>5){
         out[5] <- x[3]
         out[6] <- err[3]
-        out['rhoXZ'] <- cormat[1,3]
-        out['rhoYZ'] <- cormat[2,3]
+        out['rXZ'] <- cormat[1,3]
+        out['rYZ'] <- cormat[2,3]
     }
     if (nc>9){
         out[7] <- x[4]
         out[8] <- err[4]
-        out['rhoXW'] <- cormat[1,4]
-        out['rhoYW'] <- cormat[2,4]
-        out['rhoZW'] <- cormat[3,4]
+        out['rXW'] <- cormat[1,4]
+        out['rYW'] <- cormat[2,4]
+        out['rZW'] <- cormat[3,4]
     }
     out
 }
@@ -396,16 +502,16 @@ age_to_wetherill_ratios <- function(tt,st=0,exterr=FALSE,d=diseq()){
     labels <- c('Pb207U235','Pb206U238')
     l8 <- settings('lambda','U238')[1]
     l5 <- settings('lambda','U235')[1]
-    D <- mclean(tt=tt,d=d,exterr=exterr)
-    out$x <- c(D$Pb207U235,D$Pb206U238)
+    McL <- mclean(tt=tt,d=d,exterr=exterr)
+    out$x <- c(McL$Pb207U235,McL$Pb206U238)
     E <- matrix(0,3,3)
     diag(E) <- c(st,lambda('U235')[2],lambda('U238')[2])^2
     J <- matrix(0,2,3)
-    J[1,1] <- D$dPb207U235dt
-    J[2,1] <- D$dPb206U238dt
+    J[1,1] <- McL$dPb207U235dt
+    J[2,1] <- McL$dPb206U238dt
     if (exterr){
-        J[1,2] <- D$dPb207U235dl35
-        J[2,3] <- D$dPb206U238dl38
+        J[1,2] <- McL$dPb207U235dl35
+        J[2,3] <- McL$dPb206U238dl38
     }
     out$cov <- J %*% E %*% t(J)
     names(out$x) <- labels
@@ -420,23 +526,23 @@ age_to_terawasserburg_ratios <- function(tt,st=0,exterr=FALSE,d=diseq()){
     l8 <- lambda('U238')[1]
     U <- iratio('U238U235')[1]
     tt <- check.zero.UPb(tt)
-    D <- mclean(tt=tt,d=d,exterr=exterr)
-    U238Pb206 <- 1/D$Pb206U238
-    Pb207Pb206 <- D$Pb207U235/(U*D$Pb206U238)
-    d75dt <- D$dPb207U235dt
-    d68dt <- D$dPb206U238dt
-    d75dl35 <- D$dPb207U235dl35
-    d68dl38 <- D$dPb206U238dl38
+    McL <- mclean(tt=tt,d=d,exterr=exterr)
+    U238Pb206 <- 1/McL$Pb206U238
+    Pb207Pb206 <- McL$Pb207U235/(U*McL$Pb206U238)
+    d75dt <- McL$dPb207U235dt
+    d68dt <- McL$dPb206U238dt
+    d75dl35 <- McL$dPb207U235dl35
+    d68dl38 <- McL$dPb206U238dl38
     out$x <- c(U238Pb206,Pb207Pb206)
     E <- matrix(0,4,4)
     diag(E) <- c(st,lambda('U235')[2],lambda('U238')[2],iratio('U238U235')[2])^2
     J <- matrix(0,2,4)
-    J[1,1] <- -d68dt/D$Pb206U238^2
-    J[2,1] <- (d75dt*D$Pb206U238-D$Pb207U235*d68dt)/(U*D$Pb206U238^2)
+    J[1,1] <- -d68dt/McL$Pb206U238^2
+    J[2,1] <- (d75dt*McL$Pb206U238-McL$Pb207U235*d68dt)/(U*McL$Pb206U238^2)
     if (exterr){
-        J[1,3] <- -d68dl38/D$Pb206U238^2
-        J[2,2] <- d75dl35/(U*D$Pb206U238)
-        J[2,3] <- -Pb207Pb206*d68dl38/D$Pb206U238
+        J[1,3] <- -d68dl38/McL$Pb206U238^2
+        J[2,2] <- d75dl35/(U*McL$Pb206U238)
+        J[2,3] <- -Pb207Pb206*d68dl38/McL$Pb206U238
         J[2,4] <- -Pb207Pb206/U
     }
     out$cov <- J %*% E %*% t(J)
@@ -450,17 +556,17 @@ age_to_cottle_ratios <- function(tt,st=0,exterr=FALSE,d=diseq()){
     labels <- c('Pb206U238','Pb208Th232')
     l8 <- settings('lambda','U238')[1]
     l2 <- settings('lambda','Th232')[1]
-    D <- mclean(tt=tt,d=d,exterr=exterr)
-    Pb6U8 <- D$Pb206U238
+    McL <- mclean(tt=tt,d=d,exterr=exterr)
+    Pb6U8 <- McL$Pb206U238
     Pb8Th2 <- exp(l2*tt)-1
     out$x <- c(Pb6U8,Pb8Th2)
     E <- matrix(0,3,3)
     diag(E) <- c(st,lambda('U238')[2],lambda('Th232')[2])^2
     J <- matrix(0,2,3)
-    J[1,1] <- D$dPb206U238dt
+    J[1,1] <- McL$dPb206U238dt
     J[2,1] <- l2*exp(l2*tt)
     if (exterr){
-        J[1,2] <- D$dPb206U238dl38
+        J[1,2] <- McL$dPb206U238dl38
         J[2,3] <- tt*exp(l2*tt)
     }
     out$cov <- J %*% E %*% t(J)
@@ -482,11 +588,11 @@ age_to_Pb207U235_ratio <- function(tt,st=0,d=diseq(),exterr=FALSE){
         }
     } else {
         l5 <- lambda('U235')[1]
-        D <- mclean(tt=tt,d=d,exterr=exterr)
-        R <- D$Pb207U235
-        J <- D$dPb207U235dt
+        McL <- mclean(tt=tt,d=d,exterr=exterr)
+        R <- McL$Pb207U235
+        J <- McL$dPb207U235dt
         if (exterr){
-            J <- c(J,D$dPb207U235dl35)
+            J <- c(J,McL$dPb207U235dl35)
             sl5 <- lambda('U235')[2]
             E <- diag(c(st,sl5))^2
             R.err <- sqrt(J%*%E%*%t(J))
@@ -510,15 +616,15 @@ age_to_U235Pb207_ratio <- function(tt,st=0,d=diseq(),exterr=FALSE){
         }
     } else {
         l5 <- lambda('U235')[1]
-        D <- mclean(tt=tt,d=d,exterr=exterr)
-        R <- 1/D$Pb207U235
+        McL <- mclean(tt=tt,d=d,exterr=exterr)
+        R <- 1/McL$Pb207U235
         if (exterr){
-            J <- -c(D$dPb207U235dt,D$dPb207U235l35)/D$Pb207U235^2
+            J <- -c(McL$dPb207U235dt,McL$dPb207U235l35)/McL$Pb207U235^2
             sl5 <- lambda('U235')[2]
             E <- diag(c(st,sl5))^2
             R.err <- sqrt(J%*%E%*%t(J))
         } else {
-            J <- -D$dPb207U235dt/D$Pb207U235^2
+            J <- -McL$dPb207U235dt/McL$Pb207U235^2
             R.err <- abs(J*st)
         }
         out <- cbind(R,R.err)
@@ -538,11 +644,11 @@ age_to_Pb206U238_ratio <- function(tt,st=0,d=diseq(),exterr=FALSE){
         }
     } else {
         l8 <- lambda('U238')[1]
-        D <- mclean(tt=tt,d=d,exterr=exterr)
-        R <- D$Pb206U238
-        J <- D$dPb206U238dt
+        McL <- mclean(tt=tt,d=d,exterr=exterr)
+        R <- McL$Pb206U238
+        J <- McL$dPb206U238dt
         if (exterr){
-            J <- c(J,D$dPb206U238dl38)
+            J <- c(J,McL$dPb206U238dl38)
             sl8 <- lambda('U238')[2]
             E <- diag(c(st,sl8))^2
             R.err <- sqrt(J%*%E%*%t(J))
@@ -567,15 +673,15 @@ age_to_U238Pb206_ratio <- function(tt,st=0,d=diseq(),exterr=FALSE){
     } else {
         l8 <- lambda('U238')[1]
         tt <- check.zero.UPb(tt)
-        D <- mclean(tt=tt,d=d,exterr=exterr)
-        R <- 1/D$Pb206U238
+        McL <- mclean(tt=tt,d=d,exterr=exterr)
+        R <- 1/McL$Pb206U238
         if (exterr){
-            J <- -c(D$dPb206U238dt,D$dPb206U238l38)/D$Pb206U238^2
+            J <- -c(McL$dPb206U238dt,McL$dPb206U238l38)/McL$Pb206U238^2
             sl8 <- lambda('U238')[2]
             E <- diag(c(st,sl8))^2
             R.err <- sqrt(J%*%E%*%t(J))
         } else {
-            J <- -D$dPb206U238dt/D$Pb206U238^2
+            J <- -McL$dPb206U238dt/McL$Pb206U238^2
             R.err <- abs(J*st)
         }
         R.err <- abs(J*st)
@@ -599,15 +705,15 @@ age_to_Pb207Pb206_ratio <- function(tt,st=0,d=diseq(),exterr=FALSE){
         l8 <- lambda('U238')[1]
         tt <- check.zero.UPb(tt)
         U <- iratio('U238U235')[1]
-        D <- mclean(tt=tt,d=d,exterr=exterr)
-        R <- (1/U)*D$Pb207U235/D$Pb206U238
-        J <- (1/U)*(D$dPb207U235dt*D$Pb206U238 -
-                    D$Pb207U235*D$dPb206U238dt)/D$Pb206U238^2
+        McL <- mclean(tt=tt,d=d,exterr=exterr)
+        R <- (1/U)*McL$Pb207U235/McL$Pb206U238
+        J <- (1/U)*(McL$dPb207U235dt*McL$Pb206U238 -
+                    McL$Pb207U235*McL$dPb206U238dt)/McL$Pb206U238^2
         if (exterr){
             sl5 <- lambda('U235')[2]
             sl8 <- lambda('U238')[2]
-            d76dl35 <- (1/U)*D$dPb207U235dl35/D$Pb206U238
-            d76dl38 <- -(1/U)*D$Pb207U235*D$dPb206U238dl38/D$Pb206U238^2
+            d76dl35 <- (1/U)*McL$dPb207U235dl35/McL$Pb206U238
+            d76dl38 <- -(1/U)*McL$Pb207U235*McL$dPb206U238dl38/McL$Pb206U238^2
             J <- c(J,d76dl35,d76dl38)
             E <- diag(c(st,sl5,sl8))^2
             R.err <- sqrt(J%*%E%*%t(J))
@@ -663,7 +769,7 @@ get.Pb204U238.ratios <- function(x){
     labels <- c('Pb204U238','errPb204U238')
     if (x$format %in% c(4,6)){
         out <- subset(x$x,select=labels)
-    } else if (x$format == 5){
+    } else if (x$format %in% c(5,9)){
         Pb204U238 <- x$x[,'Pb204Pb206']/x$x[,'U238Pb206']
         errPb204U238 <-
             Pb204U238*sqrt( (x$x[,'errPb204Pb206']/x$x[,'Pb204Pb206'])^2 +
@@ -689,11 +795,17 @@ get.Pb207U235.ratios <- function(x,exterr=FALSE){
         sX <- x$x[,'errU238Pb206']
         Y <- x$x[,'Pb207Pb206']
         sY <- x$x[,'errPb207Pb206']
-        covXY <- x$x[,'rhoXY']*sX*sY
+        covXY <- x$x[,'rXY']*sX*sY
         out[,'Pb207U235'] <- R*Y/X
         relerr2 <- (sX/X)^2 -2*covXY/(X*Y) + (sY/Y)^2
         if (exterr) relerr2 <- relerr2 + (sR/R)^2
         out[,'errPb207U235'] <- sqrt(relerr2)*out[,'Pb207U235']
+    } else if (x$format %in% c(10,12)){
+        out[,'Pb207U235'] <- 1/x$x[,'U235Pb207']
+        out[,'errPb207U235'] <-
+            out[,'Pb207U235']*x$x[,'errU235Pb207']/x$x[,'U235Pb207']
+    } else {
+        stop('Invalid U-Pb format for get.Pb207U235.ratios')
     }
     out
 }
@@ -713,11 +825,15 @@ get.U235Pb207.ratios <- function(x,exterr=FALSE){
         sX <- x$x[,'errU238Pb206']
         Y <- x$x[,'Pb207Pb206']
         sY <- x$x[,'errPb207Pb206']
-        covXY <- x$x[,'rhoXY']*sX*sY
+        covXY <- x$x[,'rXY']*sX*sY
         out[,'U235Pb207'] <- X/(R*Y)
         relerr2 <- (sX/X)^2 -2*covXY/(X*Y) + (sY/Y)^2
         if (exterr) relerr2 <- relerr2 + (sR/R)^2
         out[,'errU235Pb207'] <- sqrt(relerr2)*out[,'U235Pb207']
+    } else if (x$format %in% c(10,12)){
+        out <- subset(x$x,select=labels)
+    } else {
+        stop('Invalid U-Pb format for get.U235Pb207.ratios')
     }
     out
 }
@@ -728,10 +844,12 @@ get.Pb206U238.ratios <- function(x){
     colnames(out) <- labels
     if (x$format %in% c(1,3,4,6,7)){
         out <- subset(x$x,select=labels)
-    } else if (x$format %in% c(2,5,8)){
+    } else if (x$format %in% c(2,5,8,9,11)){
         out[,'Pb206U238'] <- 1/x$x[,'U238Pb206']
         out[,'errPb206U238'] <- out[,'Pb206U238']*
             x$x[,'errU238Pb206']/x$x[,'U238Pb206']
+    } else {
+        stop('Invalid U-Pb format for get.Pb206U238.ratios')
     }
     out
 }
@@ -744,8 +862,10 @@ get.U238Pb206.ratios <- function(x){
         out[,'U238Pb206'] <- 1/x$x[,'Pb206U238']
         out[,'errU238Pb206'] <- out[,'U238Pb206']*
             x$x[,'errPb206U238']/x$x[,'Pb206U238']
-    } else if (x$format %in% c(2,5,8)){
+    } else if (x$format %in% c(2,5,8,9,11)){
         out <- subset(x$x,select=labels)
+    } else {
+        stop('Invalid U-Pb format for get.U238Pb206.ratios')
     }
     out
 }
@@ -761,14 +881,16 @@ get.Pb207Pb206.ratios <- function(x,exterr=FALSE){
         sX <- x$x[,'errPb207U235']
         Y <- x$x[,'Pb206U238']
         sY <- x$x[,'errPb206U238']
-        rhoXY <- x$x[,'rhoXY']
-        covXY <- rhoXY*sX*sY
+        rXY <- x$x[,'rXY']
+        covXY <- rXY*sX*sY
         out[,'Pb207Pb206'] <- X/(R*Y)
         relerr2 <- (sX/X)^2 - 2*covXY/(X*Y) + (sY/Y)^2
         if (exterr) relerr2 <- relerr2 + (sR/R)^2
         out[,'errPb207Pb206'] <- sqrt(relerr2)*out[,'Pb207Pb206']
     } else if (x$format %in% c(2,3,5,6,8)){
         out <- subset(x$x,select=labels)
+    } else {
+        stop('Invalid U-Pb format for get.Pb207Pb206.ratios')
     }
     out
 }
@@ -776,21 +898,45 @@ get.Pb208Th232.ratios <- function(x){
     labels <- c('Pb208Th232','errPb208Th232')
     if (x$format == 7){
         out <- x$x[,labels,drop=FALSE]
-    } else if (x$format == 8){
+    } else if (x$format%in%c(8,11)){
         ns <- length(x)
         out <- matrix(0,ns,2)
         colnames(out) <- labels
-        out[,'Pb208Th232'] <- x$x[,'Pb208Pb206']/(x$x[,'U238Pb206']*x$x[,'Th232U238'])
+        out[,'Pb208Th232'] <-
+            x$x[,'Pb208Pb206']/(x$x[,'U238Pb206']*x$x[,'Th232U238'])
         J1 <- -out[,'Pb208Th232']/x$x[,'U238Pb206']
         J2 <- 1/(x$x[,'U238Pb206']*x$x[,'Th232U238'])
         J3 <- -out[,'Pb208Th232']/x$x[,'Th232U238']
         E11 <- x$x[,'errU238Pb206']^2
         E22 <- x$x[,'errPb208Pb206']^2
         E33 <- x$x[,'errTh232U238']^2
-        E12 <- x$x[,'rhoXZ']*x$x[,'errU238Pb206']*x$x[,'errPb208Pb206']
-        E13 <- x$x[,'rhoXW']*x$x[,'errU238Pb206']*x$x[,'errTh232U238']
-        E23 <- x$x[,'rhoZW']*x$x[,'errPb208Pb206']*x$x[,'errTh232U238']
-        out[,'errPb208Th232'] <- errorprop1x3(J1,J2,J3,E11,E22,E33,E12,E13,E23)
+        if (x$format == 8){
+            E12 <- x$x[,'rXZ']*x$x[,'errU238Pb206']*x$x[,'errPb208Pb206']
+            E13 <- x$x[,'rXW']*x$x[,'errU238Pb206']*x$x[,'errTh232U238']
+            E23 <- x$x[,'rZW']*x$x[,'errPb208Pb206']*x$x[,'errTh232U238']
+        } else {
+            E12 <- x$x[,'rXY']*x$x[,'errU238Pb206']*x$x[,'errPb208Pb206']
+            E13 <- x$x[,'rXZ']*x$x[,'errU238Pb206']*x$x[,'errTh232U238']
+            E23 <- x$x[,'rYZ']*x$x[,'errPb208Pb206']*x$x[,'errTh232U238']
+        }
+        out[,'errPb208Th232'] <-
+            sqrt(errorprop1x3(J1,J2,J3,E11,E22,E33,E12,E13,E23))
+    } else if (x$format == 12){
+        ns <- length(x)
+        out <- matrix(0,ns,2)
+        colnames(out) <- labels
+        U85 <- iratio('U238U235')[1]
+        out[,'Pb208Th232'] <-
+            x$x[,'Pb208Pb207']/(x$x[,'U235Pb207']*U85*x$x[,'Th232U238'])
+        J1 <- -out[,'Pb208Th232']/x$x[,'U235Pb207']
+        J2 <- 1/(x$x[,'U235Pb207']*U85*x$x[,'Th232U238'])
+        J3 <- -out[,'Pb208Th232']/x$x[,'Th232U238']
+        E11 <- x$x[,'errU235Pb207']^2
+        E22 <- x$x[,'errPb208Pb207']^2
+        E33 <- x$x[,'errTh232U238']^2
+        E12 <- x$x[,'rXY']*x$x[,'errU235Pb207']*x$x[,'errPb208Pb207']
+        E13 <- x$x[,'rXZ']*x$x[,'errU235Pb207']*x$x[,'errTh232U238']
+        E23 <- x$x[,'rYZ']*x$x[,'errPb208Pb207']*x$x[,'errTh232U238']
     } else {
         stop('Wrong input format: no Pb208 or Th232 present in this dataset.')
     }
@@ -809,11 +955,12 @@ get.Pb208Pb206.ratios <- function(x){
         E11 <- x$x[,'errPb206U238']^2
         E22 <- x$x[,'errPb208Th232']^2
         E33 <- x$x[,'Th232U238']^2
-        E12 <- x$x[,'rhoXZ']*x$x[,'Pb206U238']*x$x[,'Pb208Th232']
-        E13 <- x$x[,'rhoXW']*x$x[,'Pb206U238']*x$x[,'Th232U238']
-        E23 <- x$x[,'rhoZW']*x$x[,'Pb208Th232']*x$x[,'Th232U238']
-        out[,'errPb208Th232'] <- errorprop1x3(J1,J2,J3,E11,E22,E33,E12,E13,E23)
-    } else if (x$format == 8){
+        E12 <- x$x[,'rXZ']*x$x[,'Pb206U238']*x$x[,'Pb208Th232']
+        E13 <- x$x[,'rXW']*x$x[,'Pb206U238']*x$x[,'Th232U238']
+        E23 <- x$x[,'rZW']*x$x[,'Pb208Th232']*x$x[,'Th232U238']
+        out[,'errPb208Th232'] <-
+            sqrt(errorprop1x3(J1,J2,J3,E11,E22,E33,E12,E13,E23))
+    } else if (x$format %in% c(8,11)){
         out <- x$x[,labels]
     } else {
         stop('Wrong input format: no Pb208 present in this dataset.')
@@ -830,7 +977,7 @@ get.Pb207U235.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),...){
         for (i in 1:ns){
             if (length(sx) < ns) sxi <- sx[1]
             else sxi <- sx[i]
-            out[i,] <- get.Pb207U235.age(x[i],sxi,exterr=exterr,d=d[i])
+            out[i,] <- get.Pb207U235.age(x[i],sxi,exterr=exterr,d=d[i],...)
         }
     } else {
         l5 <- lambda('U235')[1]
@@ -846,10 +993,10 @@ get.Pb207U235.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),...){
         } else { # apply a disequilibrium correction
             t.75 <- stats::optimise(diseq.75.misfit,x=x,d=d,
                                     interval=t.init*c(.5,2))$minimum
-            D <- mclean(tt=t.75,d=d,exterr=exterr)    
-            J[1,1] <- 1/D$dPb207U235dt                 # dt/dx
-            J[1,2] <- -D$dPb207U235dl35/D$dPb207U235dt # dt/dl35
-            J[1,3] <- -D$dPb207U235dl31/D$dPb207U235dt # dt/dl31
+            McL <- mclean(tt=t.75,d=d,exterr=exterr)    
+            J[1,1] <- 1/McL$dPb207U235dt                 # dt/dx
+            J[1,2] <- -McL$dPb207U235dl35/McL$dPb207U235dt # dt/dl35
+            J[1,3] <- -McL$dPb207U235dl31/McL$dPb207U235dt # dt/dl31
         }
         st.75 <- sqrt(J %*% E %*% t(J))
         out <- c(t.75,st.75)
@@ -857,10 +1004,19 @@ get.Pb207U235.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),...){
     }
     out
 }
-get.Pb207U235.age.UPb <- function(x,i=1,exterr=FALSE,...){
+get.Pb207U235.age.UPb <- function(x,i=NULL,exterr=FALSE,...){
     r75 <- get.Pb207U235.ratios(x)
-    get.Pb207U235.age(r75[i,'Pb207U235'],r75[i,'errPb207U235'],
-                      exterr=exterr,d=x$d[i])
+    if (is.null(i)){
+        ns <- length(x)
+        out <- matrix(0,ns,2)
+        for (j in 1:ns){
+            out[j,] <- get.Pb207U235.age.UPb(x,i=j,exterr=exterr,...)
+        }
+    } else {
+        out <- get.Pb207U235.age(r75[i,'Pb207U235'],r75[i,'errPb207U235'],
+                                 exterr=exterr,d=x$d[i],...)
+    }
+    out
 }
 get.Pb207U235.age.wetherill <- function(x,exterr=FALSE,...){
     i <- 'Pb207U235'
@@ -870,7 +1026,8 @@ get.Pb207U235.age.wetherill <- function(x,exterr=FALSE,...){
 }
 
 get.Pb206U238.age <- function(x,...){ UseMethod("get.Pb206U238.age",x) }
-get.Pb206U238.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),...){
+get.Pb206U238.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),
+                                      bayes=FALSE,plot=FALSE,...){
     ns <- length(x)
     if (ns>1){
         out <- matrix(0,ns,2)
@@ -897,14 +1054,17 @@ get.Pb206U238.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),...){
             t.68 <- tryCatch({
                 stats::optimise(diseq.68.misfit,interval=tlim,x=x,d=d)$minimum
             }, error = function(error_condition) {
+                warning("Failed to solve the Pb206U238 disequilibrium equation.")
                 t.init
             })
-            D <- mclean(tt=t.68,d=d,exterr=exterr)
-            J[1,1] <- 1/D$dPb206U238dt
-            J[1,2] <- -D$dPb206U238dl38/D$dPb206U238dt # dt/dl38
-            J[1,3] <- -D$dPb206U238dl34/D$dPb206U238dt # dt/dl34
-            J[1,4] <- -D$dPb206U238dl30/D$dPb206U238dt # dt/dl30
-            J[1,5] <- -D$dPb206U238dl26/D$dPb206U238dt # dt/dl26
+            McL <- mclean(tt=t.68,d=d,exterr=exterr)
+            J[1,1] <- 1/McL$dPb206U238dt
+            if (exterr){
+                J[1,2] <- -McL$dPb206U238dl38/McL$dPb206U238dt # dt/dl38
+                J[1,3] <- -McL$dPb206U238dl34/McL$dPb206U238dt # dt/dl34
+                J[1,4] <- -McL$dPb206U238dl30/McL$dPb206U238dt # dt/dl30
+                J[1,5] <- -McL$dPb206U238dl26/McL$dPb206U238dt # dt/dl26
+            }
         }
         st.68 <- sqrt(J %*% E %*% t(J))
         out <- c(t.68,st.68)
@@ -921,7 +1081,8 @@ get.Pb206U238.age.UPb <- function(x,i=NULL,exterr=FALSE,...){
             out[j,] <- get.Pb206U238.age.UPb(x,i=j,exterr=exterr,...)
         }
     } else {
-        out <- get.Pb206U238.age(r68[i,'Pb206U238'],r68[i,'errPb206U238'],
+        out <- get.Pb206U238.age(r68[i,'Pb206U238'],
+                                 r68[i,'errPb206U238'],
                                  exterr=exterr,d=x$d[i],...)
     }
     out
@@ -941,8 +1102,8 @@ get.Pb206U238.age.terawasserburg <- function(x,exterr=FALSE,...){
 }
 
 twslope <- function(tt=0,d=diseq()){
-    D <- mclean(tt=tt,d=d)
-    D$dPb207U235dt/D$dPb206U238dt
+    McL <- mclean(tt=tt,d=d)
+    McL$dPb207U235dt/McL$dPb206U238dt
 }
 
 get.Pb207Pb206.age <- function(x,...){ UseMethod("get.Pb207Pb206.age",x) }
@@ -968,20 +1129,20 @@ get.Pb207Pb206.age.default <- function(x,sx=0,exterr=FALSE,d=diseq(),t.68=NULL,.
         }
         if (measured.disequilibrium(d)) interval[2] <- meas.diseq.maxt(d)
         t.76 <- stats::optimise(get.76.misfit,x=x,d=d,interval=interval)$minimum
-        D <- mclean(tt=t.76,d=d,exterr=exterr)
+        McL <- mclean(tt=t.76,d=d,exterr=exterr)
         E <- matrix(0,9,9)
         E[1,1] <- sx^2
         E[2,2] <- iratio('U238U235')[2]^2
         E[3:9,3:9] <- getEl()
         J <- matrix(0,1,9)
-        J[1,1] <- -1/D$dPb207Pb206dt                # dt/dx
-        J[1,2] <- D$dPb207Pb206dU/D$dPb207Pb206dt   # dt/dU
-        J[1,3] <- D$dPb207Pb206dl38/D$dPb207Pb206dt # dt/dl38
-        J[1,4] <- D$dPb207Pb206dl35/D$dPb207Pb206dt # dt/dl35
-        J[1,5] <- D$dPb207Pb206dl34/D$dPb207Pb206dt # dt/dl34
-        J[1,7] <- D$dPb207Pb206dl31/D$dPb207Pb206dt # dt/dl31
-        J[1,8] <- D$dPb207Pb206dl30/D$dPb207Pb206dt # dt/dl30
-        J[1,9] <- D$dPb207Pb206dl26/D$dPb207Pb206dt # dt/dl26
+        J[1,1] <- -1/McL$dPb207Pb206dt                # dt/dx
+        J[1,2] <- McL$dPb207Pb206dU/McL$dPb207Pb206dt   # dt/dU
+        J[1,3] <- McL$dPb207Pb206dl38/McL$dPb207Pb206dt # dt/dl38
+        J[1,4] <- McL$dPb207Pb206dl35/McL$dPb207Pb206dt # dt/dl35
+        J[1,5] <- McL$dPb207Pb206dl34/McL$dPb207Pb206dt # dt/dl34
+        J[1,7] <- McL$dPb207Pb206dl31/McL$dPb207Pb206dt # dt/dl31
+        J[1,8] <- McL$dPb207Pb206dl30/McL$dPb207Pb206dt # dt/dl30
+        J[1,9] <- McL$dPb207Pb206dl26/McL$dPb207Pb206dt # dt/dl26
         st.76 <- sqrt( J %*% E %*% t(J) )
         out <- c(t.76,st.76)
         names(out) <- c('t76','s[t76]')
