@@ -287,8 +287,8 @@ weightedmean.other <- function(x,from=NA,to=NA,random.effects=FALSE,
 #' \code{PbPb} or \code{x} has class \code{UPb} and
 #' \code{3<x$format<7}); or
 #'
-#' \code{settings('iratio','Pb208Pb206')} and
-#' \code{settings('iratio','Pb208Pb207')} (if \code{x} has class
+#' \code{settings('iratio','Pb206Pb208')} and
+#' \code{settings('iratio','Pb207Pb208')} (if \code{x} has class
 #' \code{UPb} and \code{x$format=7} or \code{8}).
 #'
 #' \code{2}: remove the common Pb by projecting the data along an
@@ -317,7 +317,7 @@ weightedmean.UPb <- function(x,random.effects=FALSE,
                              rect.col=c("#00FF0080","#FF000080"),
                              outlier.col="#00FFFF80",sigdig=2,type=4,
                              cutoff.76=1100,oerr=3,cutoff.disc=discfilter(),
-                             exterr=TRUE,ranked=FALSE,common.Pb=0,
+                             exterr=FALSE,ranked=FALSE,common.Pb=0,
                              hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -336,7 +336,7 @@ weightedmean.PbPb <- function(x,random.effects=FALSE,
                               to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,common.Pb=2,
+                              oerr=3,exterr=FALSE,common.Pb=2,
                               ranked=FALSE,hide=NULL,omit=NULL,
                               omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
@@ -404,7 +404,7 @@ weightedmean.ArAr <- function(x,random.effects=FALSE,
                               to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,ranked=FALSE,i2i=FALSE,
+                              oerr=3,exterr=FALSE,ranked=FALSE,i2i=FALSE,
                               hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -421,7 +421,7 @@ weightedmean.KCa <- function(x,random.effects=FALSE,
                              to=NA,levels=NA,clabel="",
                              rect.col=c("#00FF0080","#FF000080"),
                              outlier.col="#00FFFF80",sigdig=2,
-                             oerr=3,exterr=TRUE,ranked=FALSE,i2i=FALSE,
+                             oerr=3,exterr=FALSE,ranked=FALSE,i2i=FALSE,
                              hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -438,7 +438,7 @@ weightedmean.ThPb <- function(x,random.effects=FALSE,
                               to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,ranked=FALSE,i2i=TRUE,
+                              oerr=3,exterr=FALSE,ranked=FALSE,i2i=TRUE,
                               hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -455,7 +455,7 @@ weightedmean.ReOs <- function(x,random.effects=FALSE,
                               to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,ranked=FALSE,i2i=TRUE,
+                              oerr=3,exterr=FALSE,ranked=FALSE,i2i=TRUE,
                               hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -472,7 +472,7 @@ weightedmean.SmNd <- function(x,random.effects=FALSE,
                               to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,ranked=FALSE,
+                              oerr=3,exterr=FALSE,ranked=FALSE,
                               i2i=TRUE,hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -489,7 +489,7 @@ weightedmean.RbSr <- function(x,random.effects=FALSE,
                               to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,i2i=TRUE,ranked=FALSE,
+                              oerr=3,exterr=FALSE,i2i=TRUE,ranked=FALSE,
                               hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -506,7 +506,7 @@ weightedmean.LuHf <- function(x,random.effects=FALSE,
                               from=NA,to=NA,levels=NA,clabel="",
                               rect.col=c("#00FF0080","#FF000080"),
                               outlier.col="#00FFFF80",sigdig=2,
-                              oerr=3,exterr=TRUE,i2i=TRUE,ranked=FALSE,
+                              oerr=3,exterr=FALSE,i2i=TRUE,ranked=FALSE,
                               hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -540,7 +540,7 @@ weightedmean.fissiontracks <- function(x,random.effects=FALSE,
                                        from=NA,to=NA,levels=NA,clabel="",
                                        rect.col=c("#00FF0080","#FF000080"),
                                        outlier.col="#00FFFF80",
-                                       sigdig=2,oerr=3,exterr=TRUE,ranked=FALSE,
+                                       sigdig=2,oerr=3,exterr=FALSE,ranked=FALSE,
                                        hide=NULL,omit=NULL,omit.col=NA,...){
     weightedmean_helper(x,random.effects=random.effects,
                         detect.outliers=detect.outliers,plot=plot,
@@ -556,7 +556,7 @@ weightedmean_helper <- function(x,random.effects=FALSE,
                                 rect.col=c("#00FF0080","#FF000080"),
                                 outlier.col="#00FFFF80",type=4,
                                 cutoff.76=1100,cutoff.disc=discfilter(),
-                                sigdig=2,oerr=3,exterr=TRUE,ranked=FALSE,
+                                sigdig=2,oerr=3,exterr=FALSE,ranked=FALSE,
                                 i2i=FALSE,common.Pb=1,units='',Th0i=0,
                                 hide=NULL,omit=NULL,omit.col=NA,...){
     tt <- get.ages(x,type=type,cutoff.76=cutoff.76,cutoff.disc=cutoff.disc,
