@@ -72,6 +72,9 @@
 #' scatterplot(dat,fit=fit)
 #' @export
 york <- function(x){
+    yorkhelper(x)
+}
+yorkhelper <- function(x,np=2){
     if (ncol(x)==4) x <- cbind(x,0)
     colnames(x) <- c('X','sX','Y','sY','rXY')
     X <- x[,'X']
@@ -108,62 +111,24 @@ york <- function(x){
     names(out$a) <- c('a','s[a]')
     names(out$b) <- c('b','s[b]')
     out$type <- 'york'
-    out <- append(out,getMSWD(X2=sum(W*(Y-b*X-a)^2),df=nrow(x)-2))
-    out
-}
-
-getMSWD <- function(X2,df){
-    out <- list()
-    out$df <- df
-    if (df>0){
-        out$mswd <- as.numeric(X2/df)
-        out$p.value <- as.numeric(1-stats::pchisq(X2,df))
-    } else {
-        out$mswd <- 1
-        out$p.value <- 1
-    }
+    out$df <- nrow(x)-np
+    out <- append(out,getMSWD(X2=sum(W*(Y-b*X-a)^2),df=out$df))
     out
 }
 
 # get fitted X and Y given a dataset x=cbind(X,sX,Y,sY,rXY),
 # an intercept a and slope b. This function is useful
 # for evaluating log-likelihoods of derived quantities
-get.york.xy <- function(XY,a,b,w=0,wtype=NA){
+get.york.xy <- function(XY,a,b){
     X <- XY[,'X']
     vX <- XY[,'sX']^2
     Y <- XY[,'Y']
     vY <- XY[,'sY']^2
     sXY <- XY[,'rXY']*XY[,'sX']*XY[,'sY']
-    if (wtype%in%c('intercept',0,'a')) vY <- vY + w^2
     O <- invertcovmat(vx=vX,vy=vY,sxy=sXY)
     N <- O[,'xx']*X + O[,'xy']*b*X + O[,'xy']*(Y-a) + b*(Y-a)*O[,'yy']
     D <- O[,'xx'] + 2*b*O[,'xy'] + O[,'yy']*b^2
-    if (wtype%in%c('slope',1,'b')){
-        slopeyorkroot <- function(p,XYi,a,b,w){
-            E <- dEdx <- matrix(0,2,2)
-            E[1,1] <- XYi['sX']^2
-            E[2,2] <- XYi['sY']^2 + (w*p)^2
-            E[1,2] <- E[2,1] <- XYi['rXY']*XYi['sX']*XYi['sY']
-            D <- c(XYi['X']-p,XYi['Y']-a-b*p)
-            dEdx[2,2] <- 2*p*w^2
-            dDdx <- c(-1,-b)
-            O <- solve(E)
-            sum(diag(O%*%dEdx)) + 2*D%*%O%*%dDdx - D%*%O%*%dEdx%*%O%*%D
-        }
-        slopeyorkhelper <- function(i,XY,a,b,w,lower,upper){
-            stats::uniroot(f=slopeyorkroot,lower=lower[i],upper=upper[i],
-                           XYi=XY[i,],a=a,b=b,w=w,extendInt='yes',
-                           tol=.Machine$double.eps^0.5)
-        }
-        ns <- nrow(XY)
-        init <- N/D
-        dx <- diff(range(XY[,'X']))
-        fit <- sapply(1:ns,slopeyorkhelper,lower=init-dx,
-                      upper=init+dx,XY=XY,a=a,b=b,w=w)
-        x <- unlist(fit[1,])
-    } else {
-        x <- N/D
-    }
+    x <- N/D
     y <- a + b*x
     cbind(x=x,y=y)
 }
@@ -183,7 +148,7 @@ get.york.xy <- function(XY,a,b,w=0,wtype=NA){
 #' @param format one of
 #'
 #' \code{1} or \code{2}: \code{X}, \code{s[X]}, \code{Y}, \code{s[Y]},
-#' \code{rho}; where \code{rho} is the error correlation between
+#' \code{rXY}; where \code{rXY} is the error correlation between
 #' \code{X} and \code{Y}; or
 #'
 #' \code{3}: \code{X/Z}, \code{s[X/Z]}, \code{Y/Z}, \code{s[Y/Z]},
@@ -248,32 +213,31 @@ data2york.other <- function(x,...){
 #' \code{sX=s[07/35]}, \code{Y=06/38}, \code{sY=s[06/38]}, \code{rXY}.
 #'
 #' \code{2}: Tera-Wasserburg ratios: \code{X=38/06},
-#' \code{sX=s[38/06]}, \code{Y=07/06}, \code{sY=s[07/06]},
-#' \code{rho=rXY}.
+#' \code{sX=s[38/06]}, \code{Y=07/06}, \code{sY=s[07/06]}, \code{rXY}.
 #'
 #' \code{3}: \code{X=38/06}, \code{sX=s[38/06]}, \code{Y=04/06},
-#' \code{sY=s[04/06]}, \code{rho=rXY} (only valid if \code{x$format=4,5}
+#' \code{sY=s[04/06]}, \code{rXY} (only valid if \code{x$format=4,5}
 #' or \code{6}).
 #'
 #' \code{4}: \code{X=35/07}, \code{sX=s[35/07]}, \code{Y=04/07},
-#' \code{sY=s[04/07]}, \code{rho=rXY} (only valid if \code{x$format=4,5}
+#' \code{sY=s[04/07]}, \code{rXY} (only valid if \code{x$format=4,5}
 #' or \code{6}).
 #'
 #' \code{5}: U-Th-Pb concordia ratios: \code{X=06/38},
 #' \code{sX=s[06/38]}, \code{Y=08/32}, \code{sY=s[08/32]},
-#' \code{rho=rXY} (only valid if \code{x$format=7,8}).
+#' \code{rXY} (only valid if \code{x$format=7,8}).
 #'
 #' \code{6}: \code{X=38/06}, \code{sX=s[38/06]}, \code{Y=08/06},
-#' \code{sY=s[08/06]}, \code{rho=rXY} (only valid if \code{x$format=7,8}).
+#' \code{sY=s[08/06]}, \code{rXY} (only valid if \code{x$format=7,8}).
 #' 
 #' \code{7}: \code{X=35/07}, \code{sX=s[35/07]}, \code{Y=08/07},
-#' \code{sY=s[08/07]}, \code{rho=rXY} (only valid if \code{x$format=7,8}).
+#' \code{sY=s[08/07]}, \code{rXY} (only valid if \code{x$format=7,8}).
 #' 
 #' \code{8}: \code{X=32/08}, \code{sX=s[32/08]}, \code{Y=06/08},
-#' \code{sY=s[06/08]}, \code{rho=rXY} (only valid if \code{x$format=7,8}).
+#' \code{sY=s[06/08]}, \code{rXY} (only valid if \code{x$format=7,8}).
 #'
 #' \code{9}: \code{X=32/08}, \code{sX=s[32/08]}, \code{Y=07/08},
-#' \code{sY=s[07/08]}, \code{rho=rXY} (only valid if \code{x$format=7,8}).
+#' \code{sY=s[07/08]}, \code{rXY} (only valid if \code{x$format=7,8}).
 #'
 #' @param tt the age of the sample. This is only used if
 #'     \code{x$format=7} or \code{8}, in order to calculate the
@@ -294,61 +258,81 @@ data2york.UPb <- function(x,option=1,tt=0,...){
             td <- tera.wasserburg(x,i=i)
             out[i,] <- data2york_UPb_helper(td,i1='U238Pb206',i2='Pb207Pb206')
         }
-    } else if (option==3 && x$format%in%c(4,5,6)){ # 04/06 vs 38/06
-        for (i in 1:ns){
-            ir <- get.UPb.isochron.ratios.204(x,i)
-            out[i,] <- data2york_UPb_helper(ir,i1='U238Pb206',i2='Pb204Pb206')
+    } else if (option==3 && x$format%in%c(4,5,6,9)){ # 04/06 vs 38/06
+        if (x$format==9){
+            out <- x$x
+        } else {
+            for (i in 1:ns){
+                ir <- get.UPb.isochron.ratios.204(x,i)
+                out[i,] <- data2york_UPb_helper(ir,i1='U238Pb206',i2='Pb204Pb206')
+            }
         }
-    } else if (option==4 && x$format%in%c(4,5,6)){ # 04/07 vs. 35/07
-        for (i in 1:ns){
-            ir <- get.UPb.isochron.ratios.204(x,i)
-            out[i,] <- data2york_UPb_helper(ir,i1='U235Pb207',i2='Pb204Pb207')
+    } else if (option==4 && x$format%in%c(4,5,6,10)){ # 04/07 vs. 35/07
+        if (x$format==10){
+            out <- x$x
+        } else {
+            for (i in 1:ns){
+                ir <- get.UPb.isochron.ratios.204(x,i)
+                out[i,] <- data2york_UPb_helper(ir,i1='U235Pb207',i2='Pb204Pb207')
+            }
         }
-    } else if (option==5 && x$format%in%c(7,8)){ # 08/32 vs. 06/38
+    } else if (option==5 && x$format%in%c(7,8,11)){ # 08/32 vs. 06/38
         for (i in 1:ns){
             wd <- wetherill(x,i=i)
             out[i,] <- data2york_UPb_helper(wd,i1='Pb206U238',i2='Pb208Th232')
-        }        
-    } else if (option==6 && x$format%in%c(7,8)){ # 08/06 vs. 38/06
+        }
+    } else if (option==6 && x$format%in%c(7,8,11)){ # 08c/06 vs. 38/06
         for (i in 1:ns){
             ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
             out[i,] <- data2york_UPb_helper(ir,i1='U238Pb206',i2='Pb208cPb206')
         }
-    } else if (option==7 && x$format%in%c(7,8)){ # 08/07 vs. 35/07
+    } else if (option==7 && x$format%in%c(7,8,12)){ # 08c/07 vs. 35/07
         for (i in 1:ns){
             ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
             out[i,] <- data2york_UPb_helper(ir,i1='U235Pb207',i2='Pb208cPb207')
         }
-    } else if (option==8 && x$format%in%c(7,8)){ # 06/08 vs. 32/08
-        for (i in 1:ns){
-            ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
-            out[i,] <- data2york_UPb_helper(ir,i1='Th232Pb208',i2='Pb206cPb208')
+    } else if (option==8 && x$format%in%c(7,8,11)){ # 06c/08 vs. 32/08
+        if (x$format==11){
+            stop('Not implemented yet')
+        } else {
+            for (i in 1:ns){
+                ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
+                out[i,] <- data2york_UPb_helper(ir,i1='Th232Pb208',i2='Pb206cPb208')
+            }
         }
-    } else if (option==9 && x$format%in%c(7,8)){ # 07/08 vs. 32/08
-        for (i in 1:ns){
-            ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
-            out[i,] <- data2york_UPb_helper(ir,i1='Th232Pb208',i2='Pb207cPb208')
+    } else if (option==9 && x$format%in%c(7,8,12)){ # 07c/08 vs. 32/08
+        if (x$format==12){
+            stop('Not implemented yet')
+        } else {
+            for (i in 1:ns){
+                ir <- get.UPb.isochron.ratios.208(x,i,tt=tt)
+                out[i,] <- data2york_UPb_helper(ir,i1='Th232Pb208',i2='Pb207cPb208')
+            }
         }
-    } else if (option==10 && x$format%in%c(4,5,6)){ # 06/38 vs. 04/38 
+    } else if (option==10 && x$format%in%c(4,5,6,9)){ # 06/38 vs. 04/38
         for (i in 1:ns){
             wd <- wetherill(x,i=i)
             out[i,] <- data2york_UPb_helper(wd,i1='Pb204U238',i2='Pb206U238')
         }
-    } else if (option==11 && x$format%in%c(4,5,6)){ # 07/35 vs. 04/35
-        J <- diag(2)
-        J[1,1] <- iratio('U238U235')[1]
+    } else if (option==11 && x$format%in%c(4,5,6,10)){ # 07/35 vs. 04/35
         for (i in 1:ns){
             wd <- wetherill(x,i=i)
-            out[i,] <- data2york_UPb_helper(wd,i1='Pb204U238',i2='Pb207U235',J=J)
+            if (x$format==10){
+                out[i,] <- data2york_UPb_helper(wd,i1='Pb204U235',i2='Pb207U235')
+            } else {
+                J <- diag(2)
+                J[1,1] <- iratio('U238U235')[1]
+                out[i,] <- data2york_UPb_helper(wd,i1='Pb204U238',i2='Pb207U235',J=J)
+            }
         }
-    } else if (option==12 && x$format%in%c(7,8)){ # 06/38 vs. 08/38
+    } else if (option==12 && x$format%in%c(7,8,11)){ # 06/38 vs. 08c/38
         J <- diag(2)
         for (i in 1:ns){
             wd <- wetherill(x,i=i)
             J[1,1] <- x$x[i,'Th232U238']
             out[i,] <- data2york_UPb_helper(wd,i1='Pb208Th232',i2='Pb206U238',J=J)
         }
-    } else if (option==13 && x$format%in%c(7,8)){ # 07/35 vs. 08/35
+    } else if (option==13 && x$format%in%c(7,8,12)){ # 07/35 vs. 08c/35
         U85 <- iratio('U238U235')[1]
         J <- diag(2)
         for (i in 1:ns){
@@ -356,14 +340,14 @@ data2york.UPb <- function(x,option=1,tt=0,...){
             J[1,1] <- x$x[i,'Th232U238']*U85
             out[i,] <- data2york_UPb_helper(wd,i1='Pb208Th232',i2='Pb207U235',J=J)
         }
-    } else if (option==14 && x$format%in%c(7,8)){ # 08/32 vs. 06/32
+    } else if (option==14 && x$format%in%c(7,8,11)){ # 08/32 vs. 06c/32
         J <- diag(2)
         for (i in 1:ns){
             wd <- wetherill(x,i=i)
             J[1,1] <- 1/x$x[i,'Th232U238']
             out[i,] <- data2york_UPb_helper(wd,i1='Pb206U238',i2='Pb208Th232',J=J)
         }
-    } else if (option==15 && x$format%in%c(7,8)){ # 08/32 vs. 07/32
+    } else if (option==15 && x$format%in%c(7,8,12)){ # 08/32 vs. 07c/32
         U85 <- iratio('U238U235')[1]
         J <- diag(2)
         for (i in 1:ns){
@@ -546,29 +530,28 @@ data2york.UThHe <- function(x,...){
 #'     \code{X}, \code{sX}, \code{Y}, \code{sY}, \code{rXY}.
 #'
 #' If \code{FALSE} and \code{type=1}, uses \code{U238Th232},
-#'     \code{errU238Th232}, \code{Th230Th232}, \code{errTh230Th232},
-#'     \code{rho}
+#' \code{errU238Th232}, \code{Th230Th232}, \code{errTh230Th232}, \code{rXY}
 #'
 #' or if \code{FALSE} and \code{type=2}, uses \code{Th232U238},
-#'     \code{errTh232U238}, \code{Th230U238}, \code{errTh230U238},
-#'     \code{rho}.
+#' \code{errTh232U238}, \code{Th230U238}, \code{errTh230U238}, \code{rXY}.
+#' 
 #' @rdname data2york
 #' @export
 data2york.ThU <- function(x,type=2,generic=TRUE,...){
     if (x$format %in% c(1,3) & type==1){
         out <- subset(x$x,select=c('U238Th232','errU238Th232',
-                                   'Th230Th232','errTh230Th232','rho'))
+                                   'Th230Th232','errTh230Th232','rXY'))
     } else if (x$format %in% c(2,4) & type==2){
         out <- subset(x$x,select=c('Th232U238','errTh232U238',
-                                   'Th230U238','errTh230U238','rho'))
+                                   'Th230U238','errTh230U238','rXY'))
     } else if (x$format %in% c(2,4) & type==1){
         out <- ThConversionHelper(x)
         colnames(out) <- c('U238Th232','errU238Th232',
-                           'Th230Th232','errTh230Th232','rho')
+                           'Th230Th232','errTh230Th232','rXY')
     } else if (x$format %in% c(1,3) & type==2){
         out <- ThConversionHelper(x)
         colnames(out) <- c('Th232U238','errTh232U238',
-                           'Th230U238','errTh230U238','rho')
+                           'Th230U238','errTh230U238','rXY')
     } else {
         stop('Incorrect data format and/or plot type')
     }
